@@ -17,15 +17,16 @@
 */
 
 #include "personactionsmodel_p.h"
-#include <kpeople/persondata.h>
-#include <kpeople/actions.h>
+#include "persondata.h"
+#include "widgets/actions.h"
 #include <QAction>
-#include <QDebug>
-#include <QPointer>
+#include "kpeople_debug.h"
 
 namespace KPeople
 {
-struct PersonActionsPrivate {
+class PersonActionsPrivate
+{
+public:
     PersonActionsPrivate()
         : person(nullptr)
     {}
@@ -75,7 +76,9 @@ void PersonActionsModel::setPersonUri(const QString &id)
 
         resetActions();
     } else {
+        beginResetModel();
         d->actions.clear();
+        endResetModel();
     }
 
     emit personChanged();
@@ -132,6 +135,10 @@ int PersonActionsModel::rowCount(const QModelIndex &parent) const
 void PersonActionsModel::triggerAction(int row) const
 {
     Q_D(const PersonActions);
+    if (d->actions.count() >= row) {
+        qWarning() << "no action in row" << row << ". Actions available:" << d->actions.count();
+        return;
+    }
     d->actions[row]->trigger();
 }
 
